@@ -179,11 +179,21 @@ class Response(object):
 
 		#
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
+		if self.log_file == None:
+			return self.error("Define the dev0s.response.log_file attribute.")
+		if not Files.exists(self.log_file): Files.create(self.log_file)
 		try:
-			logs = File(str(self.log_file), load=True, blank="").data
-		except:
-			return self.error("Failed to load the logs.")
+			logs = Files.load(self.log_file)
+		except Exception as e:
+			return self.error(f"Failed to load the logs, error: {e}.")
 		if format == "webserver":
+			while True:
+				if "<!DOCTYPE html>" in logs:
+					old = str(logs)
+					logs = String(logs).replace_between(["<!DOCTYPE html>", "</html>"], " *** HTML CODE ****")
+					if logs == old:
+						return self.error("Unable remove the html code from the logs.")
+				else: break
 			logs = logs.replace("\n", "<br>")
 		elif format == "cli":
 			a=1
@@ -195,8 +205,13 @@ class Response(object):
 			return self.error(f"Invalid format parameter [{format}], valid options: {options}.")
 
 		return self.success("Succesfully loaded the logs.", {"logs":logs})
-	def reset_logs(self):
-		Formats.File(str(self.log_file)).save(f"Resetted log file.\n")
+	def reset_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
+		Files.save(self.log_file, f"Resetted log file.\n")
+		response = self.load_logs(format=format)
+		if not response.success:  return self.error(f"Failed to load the logs after restting, error: {response.error}")
+		return self.success("Succesfully resetted the logs.", {
+			"logs":response.logs,
+		})
 		
 		#
 	
